@@ -16,7 +16,8 @@ urlpatterns = [
     path(r"geolayer/view/<str:slug>/", LayerView.as_view(), name="layerview"),
     # Extra urls from third part modules
     path("", include("terra_accounts.urls")),
-    path("", include("terra_utils.urls")),
+    path("", include("terra_settings.urls")),
+    path("", include("mapbox_baselayer.urls")),
     path("geostore/", include(geostore_patterns)),
     path(
         "geosource/",
