@@ -161,7 +161,7 @@ class LayerView(APIView):
                     ),
                     to_attr="filters_enabled",
                 ),
-                "custom_styles__source",
+                "extra_styles__source",
             )
         ),
     )
@@ -169,6 +169,8 @@ class LayerView(APIView):
     scene = None
 
     def get(self, request, slug=None, format=None):
+        update_cache = request.query_params.get("cache") == "false"
+
         self.scene = get_object_or_404(Scene, slug=slug)
         self.layergroup = self.layers.first().source.get_layer().layer_groups.first()
 
@@ -180,7 +182,11 @@ class LayerView(APIView):
             self.scene, self.user_groups.values_list("name", flat=True)
         )
 
-        response = cache.get_or_set(cache_key, self.get_response_with_sources)
+        if update_cache:
+            response = self.get_response_with_sources()
+            cache.set(cache_key, response)
+        else:
+            response = cache.get_or_set(cache_key, self.get_response_with_sources)
 
         return Response(response)
 
@@ -269,7 +275,7 @@ class LayerView(APIView):
                 SourceSerializer.get_object_serializer(layer).data,
                 *[
                     SourceSerializer.get_object_serializer(cs).data
-                    for cs in layer.custom_styles.filter(
+                    for cs in layer.extra_styles.filter(
                         source__slug__in=self.authorized_sources
                     )
                 ],
@@ -310,7 +316,7 @@ class LayerView(APIView):
         It contains, popup, minisheet and custom styles
         """
         interactions = self.get_formatted_interactions(layer)
-        for cs in layer.custom_styles.all():
+        for cs in layer.extra_styles.all():
             interactions += self.get_formatted_interactions(cs)
 
         main_field = getattr(layer.main_field, "name", None)
@@ -363,7 +369,7 @@ class LayerView(APIView):
         """Return list of sublayers of a layer"""
         return [
             layer.layer_identifier,
-            *[s.layer_identifier for s in layer.custom_styles.all()],
+            *[s.layer_identifier for s in layer.extra_styles.all()],
         ]
 
     def get_layers_tree(self, scene):
@@ -416,7 +422,7 @@ class LayerView(APIView):
     def get_layer_dict(self, layer):
         if (
             layer.source.slug not in self.authorized_sources
-            or layer.custom_styles.exclude(
+            or layer.extra_styles.exclude(
                 source__slug__in=self.authorized_sources
             ).exists()
         ):
@@ -505,7 +511,7 @@ class LayerView(APIView):
             self.model.objects.filter(group__view=self.scene.pk)
             .order_by("order")
             .select_related("source")
-            .prefetch_related("custom_styles__source")
+            .prefetch_related("extra_styles__source")
         )
 
         if layers:
